% Launch Van der Pol problem
%
% Les equations sont : [i=1,2] pi''+ wi/Qi * pi' + wi*wi * pi = Fi*[A+B(p1+p2)+C(p1+p2)^2](p1'+p2')    -    Van der Pol coupls
% 
% On reformule le systme :
%
% p1' = q1
% q1' = - w1^2*p1+a1*q1+a2*lambda*(q1+q2)+a3*lambda*w+a4*lambda*v 
% p2' = q2
% q2' =- w1^2*p2+b1*q2+b2*lambda*(q1+q2)+b3*lambda*w+b4*lambda*v
%  0   =r - (p1 + p2)^2 
%  0   =w - (p1+p2)*(q1+q2)            
%  0   =v- r*(q1+q2)  
%
%    z = [ p1 ; q1 ; p2 ; q2 ; r ; w ; v ]  (nz_tot=7)  % unknown of the DAE
%
%    ^
%    u = [ u_0 ;  u_C1 ;  u_C2 ; ...  ; u_CH ; u_S1 ;  u_S2 ; ...  ; u_SH ]  Fourier coef (colum) vector for u
%
%          ^   ^     ^
%    Z= [ p1 ; q1 ; p2 ; q2 ; r ; w ; v ]  matrix of unknown Fourier coefficients
%
%    Z= reshape(Z, nz_tot*(2*H+1),1)  -> column vector of unknown Fourier coefficients

global U Ut    % Global variables to export point from the diagram. 

addpath('../../SRC')

%% Parameters of the system
nz= 4;     % number of main equations of the DAE system
nz_aux =3;  % number of auxiliary equations of the DAE system
H = 5;     % number of harmonics

% specific parameters
parameters.w1 = 1;
parameters.w2 = 2.5;

parameters.a1=1e-02;
parameters.a2=5e-01;
parameters.a3=2;
parameters.a4=2;

parameters.b1=2.5*parameters.a1;
parameters.b2=2*parameters.a2;
parameters.b3=2*parameters.a3;
parameters.b4=2*parameters.a4;

%% initialization of the system
%sys=SystHBQ(nz,nz_aux,H,@equations,@point_display,@global_display,parameters);
sys=SystHBQ_QP(nz,nz_aux,H,@equations,@point_display,@global_display,parameters);

%% starting point

% %%% Quasi-periodic point :
% %-- Be careful of the displayed variables /!\
% load('U_H4_QP');
% [Z0,omega1,omega2,lambda] = sys.init_Hdiff(U);
% U0 = sys.init_U0(Z0,omega1,omega2,lambda);

% %%% Periodic point :
% omega = 2.5; lambda=0.026; % Behind Hopf bifs !
% Z0  =randn(2*H+1,sys.nz_tot)*1e-5;
% Z0(2,1) = .02;
% Z0(:,2) = omega*sys.D(Z0(:,1));
% Z0(2,3) = .2;
% Z0(:,4) = omega*sys.D(Z0(:,1));
% 
% Z0(:,5) = sys.Prod(Z0(:,1)+Z0(:,3),Z0(:,1)+Z0(:,3));
% Z0(:,6) = sys.Prod(Z0(:,1)+Z0(:,3),Z0(:,2)+Z0(:,4));
% Z0(:,7) = sys.Prod(Z0(:,5),Z0(:,2)+Z0(:,4));
% 
% U0 = sys.init_U0(Z0,omega,lambda);

%%% From Neimarck-Sacker bifurcation
load('Section_NS2_H5');
U0 = sys.init_NS(Section);

%% Launch of Manlab with options
Manlab('sys'       ,sys , ...
    'U0value'         ,U0, ...
    'ANMthreshold'    ,1e-8 , ...
    'NRthreshold'     ,1e-5, ...
    'NRstart'         ,1, ...
    'StabilityCheck'  ,1, ...
    'PointDisplay'    ,1, ...
    'GlobalDisplay'   ,0, ...
    'displayvariables',[ sys.neq+1  2    ;  sys.neq+1   2+2*H ]);     % MANLAB run
%                         lambda   uc w2     lambda     uc w1

    %'StabilityCheck'  ,strcmp(sys.type,'HBQ'), ... % [on] only if it is a periodic solution.
