function [Rtot] = equations(sys,Utot)
% Equations of the system of the form R(U) = C + L(U) + Q(U,U).
% The residu that defines auxiliar variables is computed and then the
% real residu of the system.

u = Utot(1:sys.neq);         % u1,u2
lambda = Utot(sys.neq+1);    % lambda
Uaux = Utot(sys.neq+2:end);  % v1, ..., v4

mu = sys.parameters.mu;

%%% Auxiliary residue
%  raux1 = v1 - 1 - u1 - u1*u1  = 0
%  raux2 = v2 - 1 - u2 - u2*u2  = 0
%  raux3 = 1 - v3*v1            = 0
%  raux4 = 1 - v4*v2            = 0
Raux(1) = Uaux(1) -1 - u(1) - u(1)*u(1);
Raux(2) = Uaux(2) -1 - u(2) - u(2)*u(2);
Raux(3) = 1 - Uaux(1)*Uaux(3);
Raux(4) = 1 - Uaux(2)*Uaux(4);

%%% Main residue
%   r1 = 2 u1 -  u2  + 100 u1 v3 -lambda       = 0
%   r2 = 2 u2 -  u1  + 100 u2 v4 -lambda - mu  = 0
R(1) = 2*u(1) - u(2) + 100*u(1)*Uaux(3) - lambda;
R(2) = 2*u(2) - u(1) + 100*u(2)*Uaux(4) - lambda -mu;

Rtot = [R Raux]';

end