%  Second order equations for Van der Pol oscillator :
% x'' + alpha x' - lambda(1-x^2)x' + x = 0.
%
%  First order recast of the form X' = f(X),
% required for stability analysis :
%  x' = y
%  y' = -alpha y + lambda (1 - x^2)y - x
%
%  Static solution f(X) = 0 :
%               y = 0
%  -alpha y + lambda (1-x^2)y - x = 0
%
%  Auxiliary variables :
%      v = lambda y
%      r = 1-x^2
%
%   Quadratic system of equations :
%       y           = 0
%   -alpha*y + v*r  = 0
%   v - lambda*y    = 0
%   r - 1 + x*x     = 0


global U Section Diagram    % Global variables to export point from the diagram. 

addpath('../../SRC')

%% parameters of the system
neq = 2;
neq_aux = 2;

% specific parameters
parameters.alpha = 0.4;

%% initialization of the system
sys=SystAQ(neq,neq_aux,@equations,@point_display,@global_display,parameters);
 
%% starting point
x = 0;
y = 0;
lambda = 0;

%%% Auxiliary variables
v = lambda*y;
r = 1-x^2;

U0tot = [x y lambda v r]';

% The bifurcation diagram represents 
% x with respect to lambda and
% y with respect to lambda :
dispvars = [neq+1 1; ...
            neq+1 2];

%% Launch Manlab
Manlab('sys'             ,sys, ...      
       'U0value'         ,U0tot, ...
       'Amax_max'        ,1, ...        % Maximum value of the radius of convergence of the series
       'StabilityCheck'  ,1, ...        % Stability an analysis [1=on | 0=off]
       'StabTol'         ,1e-6, ...     % Stability tolerance threshold.
       'displayvariables',dispvars);     % MANLAB run


