function [Rtot,dRaux] = equations(obj,Utot,dUtot)
% Quadratic system of the form R(U) = C + L(U) + Q(U,U) + f(U)
% with the differential form of the non-quadratic equations in dRaux(U,dU).

% Variables
lambda = Utot(obj.neq+1);
u = Utot(1:obj.neq); du = dUtot(1:obj.neq);
Uaux = Utot(obj.neq+2:end); dUaux = dUtot(obj.neq+2:end);
% Residues
R = zeros(obj.neq,1);
Raux = zeros(obj.neq_aux,1);                dRaux = zeros(obj.neq_aux,1);

% Definition of the auxiliary variables     | differentiation of the non-quadratic equations
% raux1 = -1  +   v1   -  u1*u2                    
% raux2 =  0  +  5u1   +  v1*v2                    
% raux3 =  0  +   v3   +    0   - tanh(v2)  | draux3 = dv3 - v4*dv2
% raux4 = -1  +   v4   +  v3*v3                    
% raux5 =  0  +   v5   +    0   - exp (u2)  | draux5 = dv5 - v5*du2
% raux6 =  0  +  v6-v5 +  u1*v6       

Raux(1) = -1 + Uaux(1) - u(1)*u(2);
Raux(2) = 5*u(1) + Uaux(1)*Uaux(2);
Raux(3) = Uaux(3) - tanh(Uaux(2));          dRaux(3) = dUaux(3) - Uaux(4)*dUaux(2);
Raux(4) = -1 + Uaux(4) + Uaux(3)*Uaux(3);
Raux(5) = Uaux(5) - exp(u(2));              dRaux(5) = dUaux(5) - Uaux(5)*du(2);
Raux(6) = Uaux(6)-Uaux(5) + u(1)*Uaux(6);

% Equation of the original system
% r1 =  u1  +  lambda*v6                
% r2 =  u2  +  u1*v3                    
R(1) = u(1) + lambda*Uaux(6);
R(2) = u(2) + u(1)*Uaux(3);

Rtot=[R ; Raux];

end