function [Rtot,dRaux,Forcing] = equations(sys,t,Utot,dUtot,d2Utot)
 
%    DAE for the forced duffing model ( u' = v // v' = - epsilon*v - u - u^3 = alpha*cos(lambda t)  (nz=2)
%
% The derivated terms should be with a -1 and the forced term is
% isolated on the right hand side, as follows :
%
%    y                   - x'  = 0
%  - x - epsilon y - r*x - y'  = - alpha cos(lambda t)
%    r             - x^2       = 0

%%% parameters of the system
alpha = sys.parameters.alpha;
epsilon = sys.parameters.epsilon;

%%% variables of the system
x = Utot(1);dx=dUtot(1);
y = Utot(2);dy=dUtot(2);
r = Utot(3);
lambda = Utot(end); % unused here because it is the forcing pulsation.

%%% Auxiliary equations
Raux = zeros(sys.nz_aux,1);     dRaux = zeros(sys.nz_aux,1);
Raux(1) = r - x^2;

%%% Physical equations
R = zeros(sys.nz,1);
R(1) = y - dx;
R(2) = - x - epsilon*y - r*x - dy;

%%% All the equations of the quadratic system
Rtot = [R;Raux];

%%% Forcing terms
% Should be written as if the forcing pulsation value is 1
% i.e. the forcing period is 2*pi
Forcing = zeros(2*sys.H+1,sys.nz_tot);
Forcing(:,2) = -alpha*cos(t);

end