function [] = global_display(sys,Section)
% function [] = global_display(sys,Section)
% Section is a 'CheckPoint class' object 
% containing all the information about the series:
% discrete representation, bifurcation analysis,...

Upp = Section.Upp; % Point representation of the series

H=sys.H;
nz_tot=sys.nz_tot;
tol_h = 10*sys.NRthreshold;

nb_pt = size(Upp,2);

h = zeros(nb_pt,nz_tot);
omega = zeros(nb_pt,1);

%% Loop on the point representation of the series
for k = 1:nb_pt 
    
    Uk = Upp(:,k);
    [Zk,omega(k),~] = sys.get_Ztot(Uk);
    
    %%% Loop on all of the unknowns 
    for i=1:nz_tot
        norm_Z = norm(Zk(:,i));      % Total energy os the i-th variable
        trunc_norm_Z = norm(Zk(1,i));% Energy of the i-th variable truncated at H=0
        %%% Determination of the number of harmonics h(k,i) needed 
        % so that most of the energy (at the tolerance tol_h) 
        % is contained in the Fourier series truncated at order h(k,i).
        while (trunc_norm_Z/norm_Z< 1-tol_h)
            h(k,i) = h(k,i)+1;
            ind = [     (1:h(k,i)+1)        (H+2:H+1+h(k,i)) ];
            %       cst and cosine indices    sin indices.
            trunc_norm_Z = norm(Zk(ind,i));
        end
    end

end

figure(5);
% Plot of the energetic criteria for the convergence of the Fourier series.
for i=1:nz_tot
    if i>sys.nz; color = 'b'; else; color = 'r'; end
    % the auxiliary variables are plotted in blue.
    pl(i)=plot(omega,h(:,i),[color '-*']);hold on;grid on;
end
format short e
title(['Number of harmonics needed to reach the Fourier norm with ' num2str(tol_h) ' precision.'])
legend([pl(1) pl(end)],'Main variables','Auxiliary variables','Location','SouthEast');


end
