% Second order equation of the Pendulum : 
% x'' + lambda x' + sin(x) = 0 (nz=1)
%
% Quadratic recast :
% x'' + lambda x' + s = 0
% s = sin(x)
%
% A companion variable c = cos(x) must be added to s = sin(x) 
% to recast its differential form quadratically :
%
% s = sin(x) | s' =   x' * c (nz_aux = 2)
% c = cos(x) | c' = - x' * s
%
%%% Final recast (nz_tot = 3) :
% x'' + lambda x' + s = 0
% s - sin(x)          = 0  | s' -   x' * c = 0
% c - cos(x)          = 0  | c' +   x' * s = 0
%
%   The unknowns are the Fourier coefficients of U=[x] and Uaux=[s;c].
%   They are sorted like following :
%    x = [ x_0 ;  x_C1 ;  x_C2 ; ...  ; x_CH ; x_S1 ;  x_S2 ; ...  ; x_SH ]
%    Fourier coef (colum) vector for x
%
%   The total vector of unknowns Utot is then constructed from U, Uaux, lambda
%   and omega (the pulsation of the oscillation) :
%
%   [U ; omega ; lambda ; Uaux] (of size nz_tot*(2*H+1)+2)
%
% To recast quadratically the second order derivatives x'' and the term
% lambda*x', two auxiliary variables are added : omega^2 and lambda*omega.
%
% This gives :
%
%   Utot = [U ; omega ; lambda ; Uaux ; omega^2 ; lambda*omega] 
%   of size nz_tot*(2*H+1)+2

global U Section Diagram    % Global variables to export point from the diagram.

addpath('../../SRC')

%% Parameters of the system
nz= 1;     % number of main equations of the DAE system
nz_aux =2;  % number of auxiliary equations of the DAE system
H = 20;     % number of harmonics
parameters = struct();

%% initialization of the system
sys=SystHBQ(nz,nz_aux,H,@equations,@point_display,@global_display,parameters);

%% starting point
nz_tot=nz+nz_aux;
Z0  =randn(2*H+1,nz_tot)*1e-10;
% Z0 = [x,s,c] is a vector of Fourier coefficients.
% Each variable corresponds to a column of Z0, 
% the 2H+1 lines being the constant value (line 1) 
% plus the cos/sin of the H harmonics (c_1,c_2,...,c_H,s_1,s_2,...s_H)
lambda=0;omega=1;
Z0(2,1)=0.01 ;      % c_1 of x set to 0.01

% Auxiliary variables
Z0(:,2) = Z0(:,1);  % sin(x) ~= x for x<<1 
Z0(1,3) = 1;        % cos(x) ~= 1 for x<<1

% The bifurcation diagram represents
% first cosine of x with respect to omega and
% first sine of x with respect to omega :
dispvars = [sys.neq 2; ...
    sys.neq 2+H];

%% Launch of Manlab with options
Manlab('sys'       ,sys , ...
    'U0value'         ,sys.init_U0(Z0,omega,lambda) , ...
    'ANMthreshold'    ,1e-14 , ...
    'NRthreshold'     ,1e-11, ...
    'displayvariables',dispvars);     % MANLAB run
%                        omega   uc2

