%  Second order equations for Van der Pol oscillator :
% x'' + alpha x' - lambda(1-x^2)x' + x = 0.
%
%  First order recast of the form X' = f(X),
% required for stability analysis :
%  x' = y
%  y' = -alpha y + lambda (1 - x^2)y - x
%
%  Auxiliary variables :
%      v = lambda y
%      r = 1-x^2
%
%   Quadratic system of equations :
%    0 = y - x'
%    0 = -alpha y + v*r - x - y'
%    0 = v - lambda*y
%    0 = r - 1 + x^2
%

warndlg(['/!\ This is an advanced example that shows how to compute the periodic ', ...
    'limit cycle that appears after a Hopf bifurcation. Do not use it ', ...
    'as a first example. /!\']);

global U Section Diagram    % Global variables to export point from the diagram.

addpath('../../SRC')

%% parameters of the system
nz = 2;
nz_aux = 2;
H = 10;

% specific parameters
parameters.alpha = 0.4;

%% initialization of the system
sys=SystHBQ(nz,nz_aux,H,@equations,@point_display,@global_display,parameters);

%% starting point
% From the Hopf bifurcation.
% see ../Examples_AQ/VDPstab for the computation of 'Section_Hopf'.

load('Section_Hopf');
U0tot = sys.init_Hopf(Section); % Automatic initialization from a Hopf point.
[Z0tot,omega,lambda]=sys.get_Ztot(U0tot);
% Computation of the last auxiliary variable more accurately 
% as the stability analysis gives only the first harmonic.
Z0tot(:,4) = 0;
Z0tot(1,4) = 1;
Z0tot(:,4) = Z0tot(:,4) - sys.Prod(Z0tot(:,1),Z0tot(:,1));

U0tot = sys.init_U0(Z0tot,omega,lambda);

% The bifurcation diagram represents
% first cosine of x with respect to lambda and
% first sine of x with respect to lambda :
dispvars = [sys.neq+1 2; ...
    sys.neq+1 2+H];

%% Launch Manlab
Manlab('sys'             ,sys, ...
    'U0value'         ,U0tot, ...
    'NRstart'         ,0, ... % Correction of the initial guess off
    'StabilityCheck'  ,1, ...
    'displayvariables',dispvars);     % MANLAB run


